summaryrefslogtreecommitdiffstats
path: root/chrome/browser/modal_html_dialog_delegate.h
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
commit57c6a6579cf274fe37d6196931a3034d90da7113 (patch)
treeec42313580156ccc039b5fee714ee12259cb08ee /chrome/browser/modal_html_dialog_delegate.h
parentb23c9e1f05d474adc327c85d87eacc77554976e0 (diff)
downloadchromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.zip
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.gz
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.bz2
Replace all occurrances of WebContents with TabContents.
Review URL: http://codereview.chromium.org/99177 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@15194 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/modal_html_dialog_delegate.h')
-rw-r--r--chrome/browser/modal_html_dialog_delegate.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/browser/modal_html_dialog_delegate.h b/chrome/browser/modal_html_dialog_delegate.h
index a17679f..f2822e3 100644
--- a/chrome/browser/modal_html_dialog_delegate.h
+++ b/chrome/browser/modal_html_dialog_delegate.h
@@ -21,7 +21,7 @@ class ModalHtmlDialogDelegate
int width, int height,
const std::string& json_arguments,
IPC::Message* sync_result,
- WebContents* contents);
+ TabContents* contents);
~ModalHtmlDialogDelegate();
// Notification service callback.
@@ -39,12 +39,12 @@ class ModalHtmlDialogDelegate
private:
// Invoked from the destructor or when we receive notification the web
// contents has been disconnnected. Removes the observer from the WebContents
// and NULLs out contents_.
void RemoveObserver();
- // The WebContents that opened the dialog.
- WebContents* contents_;
+ // The TabContents that opened the dialog.
+ TabContents* contents_;
// The parameters needed to display a modal HTML dialog.
HtmlDialogUI::HtmlDialogParams params_;
@@ -39,12 +39,12 @@ class ModalHtmlDialogDelegate
private:
// Invoked from the destructor or when we receive notification the web
- // contents has been disconnnected. Removes the observer from the WebContents
+ // contents has been disconnnected. Removes the observer from the TabContents
// and NULLs out contents_.
void RemoveObserver();